@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Restrict Senders Plugin
-  * Copyright (c) 2004-2007 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2004-2008 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -69,16 +69,16 @@ function restrict_senders_configtest_do()
    if (!check_sm_version(1, 5, 2))
    {
 
-      // try to find Compatibility, and then that it is v2.0.7+
+      // try to find Compatibility, and then that it is v2.0.10+
       //
       if (function_exists('check_plugin_version')
-       && check_plugin_version('compatibility', 2, 0, 7, TRUE))
+       && check_plugin_version('compatibility', 2, 0, 10, TRUE))
          return FALSE;
 
 
       // something went wrong
       //
-      do_err('Windows plugin requires the Compatibility plugin version 2.0.7+', FALSE);
+      do_err('Restrict Senders plugin requires the Compatibility plugin version 2.0.10+', FALSE);
       return TRUE;
 
    }
@@ -397,7 +397,9 @@ function check_restrict_senders_do(&$argv)
           $restrictSubsequentMassEmails, $vlogin_restrictSubsequentMassEmails,
           $restrictSubsequentMassEmailsWhitelist, $isMassMailing,
           $vlogin_restrictSubsequentMassEmailsWhitelist, $rs_debug,
-          $whitelisted_addresses, $rs_delimiter;
+          $whitelisted_addresses, $rs_delimiter, $log_too_many_recipients,
+          $log_too_many_today, $log_too_many_subsequent_mass_emails,
+          $log_no_recipients;
 
 
    if (check_sm_version(1, 5, 2))
@@ -511,6 +513,19 @@ function check_restrict_senders_do(&$argv)
                   $sentDates .= date('H:i:s Y-m-d', $time) . "\n";
 
 
+//FIXME: could move the logging and sending of alert down below after we let the whitelist-only messages go through...??  but maybe we want to know anyway??
+               // log this event - note that to use this,
+               // you'll need to have the Squirrel Logger plugin
+               // installed and activated and you'll have to add
+               // a "RESTRICT_SENDERS" event type to its configuration
+               //
+               if ($log_too_many_subsequent_mass_emails && is_plugin_enabled('squirrel_logger'))
+               {
+                  include_once(SM_PATH . 'plugins/squirrel_logger/functions.php');
+                  sl_logit('RESTRICT_SENDERS', sprintf('%d mass emails of %d or more recipients in the last %d minutes have been sent; BANNING this user.  To un-ban this user, remove the USER_IS_POSSIBLE_SPAMMER setting from their preferences.', sizeof($newTimes), $mass_email_recips, $number_minutes));
+               }
+
+
                // send alert to admin
                //
                sq_change_text_domain('restrict_senders');
@@ -537,6 +552,7 @@ function check_restrict_senders_do(&$argv)
                                     $whitelisted_addresses, $rs_delimiter))
             return;
 
+
          // redirect user w/out sending the mail
          //
          global $color, $send_to, $send_to_cc, $send_to_bcc, $subject, $body,
@@ -579,6 +595,18 @@ function check_restrict_senders_do(&$argv)
       && $restrictNumberOfRecipients < sizeof($toDomains) + sizeof($ccDomains) + sizeof($bccDomains))
    {
 
+      // log this event - note that to use this,
+      // you'll need to have the Squirrel Logger plugin
+      // installed and activated and you'll have to add
+      // a "RESTRICT_SENDERS" event type to its configuration
+      //
+      if ($log_too_many_recipients && is_plugin_enabled('squirrel_logger'))
+      {
+         include_once(SM_PATH . 'plugins/squirrel_logger/functions.php');
+         sl_logit('RESTRICT_SENDERS', sprintf('Too many recipients (%d); message blocked', sizeof($toDomains) + sizeof($ccDomains) + sizeof($bccDomains)));
+      }
+
+
       global $color, $send_to, $send_to_cc, $send_to_bcc, $subject, $body,
              $variable_sent_folder, $PHP_SELF;
       sqgetGlobalVar('variable_sent_folder', $variable_sent_folder);
@@ -646,6 +674,20 @@ function check_restrict_senders_do(&$argv)
                                     $whitelisted_addresses, $rs_delimiter))
             return;
 
+
+//FIXME: move this above the block above that lets whitelisted addresses through?
+         // log this event - note that to use this,
+         // you'll need to have the Squirrel Logger plugin
+         // installed and activated and you'll have to add
+         // a "RESTRICT_SENDERS" event type to its configuration
+         //
+         if ($log_too_many_today && is_plugin_enabled('squirrel_logger'))
+         {
+            include_once(SM_PATH . 'plugins/squirrel_logger/functions.php');
+            sl_logit('RESTRICT_SENDERS', sprintf('Too many messages in one day (%d); message blocked', $restrictNumberOfEmailsPerDay));
+         }
+
+
          global $color, $send_to, $send_to_cc, $send_to_bcc, $subject, $body,
                 $variable_sent_folder, $PHP_SELF;
          sqgetGlobalVar('variable_sent_folder', $variable_sent_folder);
@@ -808,6 +850,18 @@ function check_restrict_senders_do(&$argv)
     && sizeof($message->rfc822_header->cc) == 0
     && sizeof($message->rfc822_header->bcc) == 0)
    {
+      // log this event - note that to use this,
+      // you'll need to have the Squirrel Logger plugin
+      // installed and activated and you'll have to add
+      // a "RESTRICT_SENDERS" event type to its configuration
+      //
+      if ($log_no_recipients && is_plugin_enabled('squirrel_logger'))
+      {
+         include_once(SM_PATH . 'plugins/squirrel_logger/functions.php');
+         sl_logit('RESTRICT_SENDERS', 'All recipients are blacklisted per sender restriction rules');
+      }
+
+
       global $color, $send_to, $send_to_cc, $send_to_bcc, $subject, $body,
              $variable_sent_folder, $PHP_SELF;
       sqgetGlobalVar('variable_sent_folder', $variable_sent_folder);
@@ -1466,72 +1520,22 @@ function rs_report_abuse($error, $title='', $message='')
    $body .= ob_get_contents();
    ob_end_clean();
 
-   $report = new Message();
-   $header  = new Rfc822Header();
-
-   $report->setBody($body);
-   $content_type = new ContentType('text/plain');
-   global $special_encoding, $default_charset;
-   if ($special_encoding)
-      $rfc822_header->encoding = $special_encoding;
-   else
-      $rfc822_header->encoding = '8bit';
-   if ($default_charset)
-      $content_type->properties['charset']=$default_charset;
-   $header->content_type = $content_type;
-
-   $header->parseField('To', $rs_report_addresses);
-   $header->parseField('From', 'noreply');
-   $header->parseField('Subject', _("[WEBMAIL ABUSE]")
-                     . (empty($title) ? '' : ': ' . $title)
-                     . ' (' . $username . ')');
-   $report->rfc822_header = $header;
-//sm_print_r($report);exit;
-
-
-
-   global $useSendmail;
-
-
-
-   // ripped from compose.php (1.4.4)
-   //
-    if (!$useSendmail) {
-        require_once(SM_PATH . 'class/deliver/Deliver_SMTP.class.php');
-        $deliver = new Deliver_SMTP();
-        global $smtpServerAddress, $smtpPort, $pop_before_smtp, $smtp_auth_mech;
-
-        $authPop = (isset($pop_before_smtp) && $pop_before_smtp) ? true : false;
-
-        if ($smtp_auth_mech == 'none' && !$authPop) {
-                $user = '';
-                $pass = '';
-        } else {
-                global $key, $onetimepad;
-                $user = $username;
-                $pass = OneTimePadDecrypt($key, $onetimepad);
-        }
-
-        $stream = $deliver->initStream($report,$domain,0,
-                $smtpServerAddress, $smtpPort, $user, $pass, $authPop);
-    } else {
-        require_once(SM_PATH . 'class/deliver/Deliver_SendMail.class.php');
-        global $sendmail_path;
-        $deliver = new Deliver_SendMail();
-        $stream = $deliver->initStream($report,$sendmail_path);
-    }
-
-
-    $succes = false;
-    if ($stream) {
-        $length = $deliver->mail($report, $stream);
-        $succes = $deliver->finalizeStream($stream);
-    }
 
+   $subject = _("[WEBMAIL ABUSE]")
+            . (empty($title) ? '' : ': ' . $title)
+            . ' (' . $username . ')';
 
 
    sq_change_text_domain('squirrelmail');
 
+
+   // function found in SM core 1.5.2+ and Compatibility plugin 2.0.11+
+   // (suppress include error, since file is only needed for 1.5.2+,
+   // otherwise Compatibility has us covered)
+   //
+   @include_once(SM_PATH . 'functions/compose.php');
+   $success = sq_send_mail($rs_report_addresses, $subject, $body, 'noreply@' . $domain);
+
 }
 
 
